@@ -1,10 +1,8 @@
-from django.contrib.syndication.views import FeedDoesNotExist
-from django.contrib.sites.models import Site
-from django.contrib.syndication.views import Feed
-from django.contrib.contenttypes.models import ContentType
 from django.contrib.comments.models import Comment
+from django.contrib.contenttypes.models import ContentType
+from django.contrib.sites.models import Site
+from django.contrib.syndication.views import Feed, FeedDoesNotExist
 from django.core.urlresolvers import reverse
-from django.template.loader import render_to_string
 
 from taggit.models import Tag
 
@@ -13,9 +11,15 @@ from vellum.models import Post, Category
 
 
 class PostFeed(Feed):
-    _site = Site.objects.get_current()
-    title = _site.name
     description = settings.BLOG_DESCRIPTION
+    title_template = 'feeds/post_title.html'
+    description_template = 'feeds/post_description.html'
+
+    def title(self, obj):
+        site = Site.objects.get_current().name
+        if obj:
+            return '%s: %s' % (site, obj)
+        return site
 
     def link(self):
         return reverse('vellum')
@@ -23,26 +27,20 @@ class PostFeed(Feed):
     def items(self):
         return Post.objects.published()[:settings.BLOG_FEEDSIZE]
     
-    def item_title(self, item):
-        return render_to_string('vellum/feed/item_title.html', {'post': item})
-
-    def item_description(self, item):
-        return render_to_string('vellum/feed/item_description.html',
-                                {'post': item})
-
     def item_pubdate(self, obj):
         return obj.publish
 
+    def item_author_name(self, item):
+        return item.author
 
-class CategoryFeed(Feed):
+    def item_categories(self, item):
+        return item.categories.all()
 
+
+class CategoryFeed(PostFeed):
     def get_object(self, request, slug):
         return Category.objects.get(slug__exact=slug)
 
-    def title(self, obj):
-        _site = Site.objects.get_current()
-        return '%s: %s' % (_site.name, obj.title)
-
     def link(self, obj):
         if not obj:
             raise FeedDoesNotExist
@@ -51,29 +49,14 @@ class CategoryFeed(Feed):
     def description(self, obj):
         return "Posts recently categorized as %s" % obj.title
     
-    def item_title(self, item):
-        return render_to_string('vellum/feed/item_title.html', {'post': item})
-
     def items(self, obj):
         return obj.post_set.published()[:settings.BLOG_FEEDSIZE]
 
-    def item_description(self, item):
-        return render_to_string('vellum/feed/item_description.html',
-                                {'post': item})
-
-    def item_pubdate(self, obj):
-        return obj.publish
-
-
-class TagFeed(Feed):
 
+class TagFeed(CategoryFeed):
     def get_object(self, request, slug):
         return Tag.objects.get(slug__exact=slug)
 
-    def title(self, obj):
-        _site = Site.objects.get_current()
-        return '%s: %s' % (_site.name, obj.name)
-
     def link(self, obj):
         if not obj:
             raise FeedDoesNotExist
@@ -82,19 +65,9 @@ class TagFeed(Feed):
     def description(self, obj):
         return "Posts recently tagged with %s" % obj.name
     
-    def item_title(self, item):
-        return render_to_string('vellum/feed/item_title.html', {'post': item})
-
     def items(self, obj):
         return Post.objects.published().filter(tags__name__in=[obj.name])[:settings.BLOG_FEEDSIZE]
 
-    def item_description(self, item):
-        return render_to_string('vellum/feed/item_description.html',
-                                {'post': item})
-
-    def item_pubdate(self, obj):
-        return obj.publish
-
 
 class CommentsFeed(Feed):
     _site = Site.objects.get_current()
